@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0804';
+our $VERSION = '0.0805';
 
 use Moo;
 use strictures 2;
@@ -230,7 +230,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0804
+version 0.0805
 
 =head1 SYNOPSIS
 
@@ -238,7 +238,7 @@ version 0.0804
 
   my $mdp = Music::Duration::Partition->new(
     size => 8,                  # 2 measures in 4/4 time
-    pool => [qw(hn dqn qn en)], # Made from these durations
+    pool => [qw(hn dqn qn en)], # made from these durations
   );
 
   # the pool may also be weighted
@@ -255,7 +255,7 @@ version 0.0804
   );
 
   my $motif  = $mdp->motif;  # list-ref of pool members
-  my @motifs = $mdp->motifs; # list-ref of individual motifs
+  my @motifs = $mdp->motifs; # list of motifs
 
   # midi usage:
   # use List::Util qw(shuffle);
